/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.osgi.impl;

import java.util.Map;

import org.osgi.framework.Bundle;
import org.ow2.jasmine.rules.AbstractDroolsWorkingMemoryPool;
import org.ow2.jasmine.rules.osgi.api.IPackageAdder;

/**
 * An abstract implementation of {@link IPackageAdder}
 * 
 * @author Julien Nicoulaud
 * @see {@link DrlPackageAdder}
 * 
 */
public abstract class AbstractPackageAdder implements IPackageAdder {
	
	// -------------------------------------------------------------------------
	// Variables
	// -------------------------------------------------------------------------
	
    /**
     * Bundle containing rules.
     */
    protected final Bundle bundle;

    /**
     * Globals
     */
    protected final Map<String, Object> globals;

    /**
     * The targeted working memory name
     * @see OSGiDroolsWorkingMemoryPool
     */
    protected final String workingMemoryName;
    
    
	// -------------------------------------------------------------------------
	// Constructors
	// -------------------------------------------------------------------------
    
    /**
     * Create a new package adder to add rules belonging to a given bundle
     * into a working memory.
     * 
     * @param bundle the bundle containing rules
     * @param globals the globals
     * @param workingMemoryName the targeted working memory name
     */
    public AbstractPackageAdder(final Bundle bundle,
    					   		Map<String, Object> globals,
    					   		final String workingMemoryName) {
    	
    	this.bundle = bundle;
        this.globals = globals;
        this.workingMemoryName = workingMemoryName;
    }
    
    /**
     * Create a new package adder to add rules belonging to a given bundle
     * into the default working memory.
     * 
     * @param bundle the bundle containing rules
     * @param globals the globals
     */
    public AbstractPackageAdder(final Bundle bundle,
    					   		Map<String, Object> globals) {
    	
        this(bundle,
        	 globals,
        	 AbstractDroolsWorkingMemoryPool.DEFAULT_WORKING_MEMORY_NAME);
    }

    
	// -------------------------------------------------------------------------
	// Implementation of IPackageAdder
	// -------------------------------------------------------------------------

    /**
     * @return the bundle containing rules
     */
    public Bundle getBundle() {
        return bundle;
    }
    
    /**
     * Get the globals defined for this package
     * @return a map (name,object)
     */
    public Map<String, Object> getGlobals() {
        return globals;
    }
    
    /**
     * Get the targeted working memory name for the package
     * @return the name as String
     */    
    public String getWorkingMemoryName(){
    	return workingMemoryName;
    }
    
}
