/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.model;

/**
 * A Rule package. Each rule package is identified by the couple
 * (ruleEngineInstanceName,systemName).
 *
 * @author Julien Nicoulaud
 */
public interface IRulePackage extends IRulePackageMember {

    // =========================================================================
    // Properties
    // =========================================================================

    /**
     * The unique system name of the rule package. Identifies the object, must be
     * different for each rule package. Automatically generated from the rule
     * package "display" name.
     * @example "org.ow2.jasmine.monitoring.rules.example.ExamplePackage"
     */
    void setSystemName(String value);
    String getSystemName();

    /**
     * The previous systemName of the package in the case where it
     * was modified. Used to identify the old rule package in the database.
     */
    void setPreviousSystemName(String value);
    String getPreviousSystemName();

    /**
     * The displayed name of the rule package. This is the name that is chosen by
     * the user. Used to generate automatically the systemName property.
     * @example "Example Package"
     */
    void setDisplayName(String value);
    String getDisplayName();

    /**
     * The name of the rule engine instance on which the rule is executed.
     */
    void setRuleEngineInstanceName(String value);
    String getRuleEngineInstanceName();

    /**
     * The state of the rule package. Values can be:
     *   - Activated
     *   - Deactivated
     *   - Activation requested
     *   - Deactivation requested
     */
    void setState(String value);
    String getState();

    /**
     * The description of the rule package.
     */
    void setDescription(String value);
    String getDescription();
}
