/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.model.visual;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlElementRefs;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.ow2.jasmine.rules.manager.model.AbstractRulePackageMember;

/**
 * An element of the LHS part (when) of a rule: a logical expression.
 *
 * @author Julien Nicoulaud
 */
@XmlRootElement(name = "logical-expression")
public class LogicalExpression extends AbstractRulePackageMember
                               implements ILogicalExpression {

    // =========================================================================
    // Properties
    // =========================================================================

    /**
     * Class version ID.
     */
    private static final long serialVersionUID = 1490850185807402023L;

    /**
     * The operator.
     */
    @XmlTransient
    public String operator = "OR";

    /**
     * The operands list.
     */
    @XmlTransient
    public List<ILHSElement> operands = new ArrayList<ILHSElement>();


    // =========================================================================
    // Getters and setters
    // =========================================================================

    /**
     * Set the operator.
     */
    public void setOperator(final String value) {
        operator = value;
    }

    /**
     * Get the operator.
     */
    @XmlAttribute
    public String getOperator() {
        return operator;
    }

    /**
     * Set the operands list.
     */
    public void setOperands(final List<ILHSElement> value) {
        operands = value;
    }

    /**
     * Get the operands list.
     */
    @XmlElementWrapper(name = "operands")
    @XmlAnyElement(lax = true)
    @XmlElementRefs({
        @XmlElementRef(name = "lhs-code-snippet", type = LHSCodeSnippet.class),
        @XmlElementRef(name = "logical-expression", type = LogicalExpression.class)
    })
    public List<ILHSElement> getOperands() {
        return operands;
    }


    // =========================================================================
    // Implementation of IRulePackageMember
    // =========================================================================

    /**
     * Get the generated source in Drools syntax
     */
    public String getDrlSource() {
        String source = "(";

        // Format conditions
        Boolean first = true;
        for (ILHSElement operand : operands) {
            if (first) {
                first = false;
            } else {
                source += ' ' + operator + ' ';
            }
            source += operand.getDrlSource();
        }
        source += ")";

        return source;
    }
}
