package org.ow2.jasmine.rules.cluster.cmi.ejb;

import java.net.InetAddress;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.UUID;

import javax.ejb.EJBObject;
import javax.management.remote.JMXServiceURL;

import org.ow2.cmi.controller.common.ClusterViewManagerException;
import org.ow2.cmi.controller.server.ProtocolNotFoundException;
import org.ow2.cmi.controller.server.ServerClusterViewManagerException;
import org.ow2.cmi.ha.SessionId;
import org.ow2.cmi.info.ClusteredObjectInfo;
import org.ow2.cmi.lb.policy.IPolicy;
import org.ow2.cmi.lb.strategy.IStrategy;
import org.ow2.cmi.reference.CMIReference;
import org.ow2.cmi.reference.ObjectNotFoundException;
import org.ow2.cmi.reference.ServerId;
import org.ow2.cmi.reference.ServerNotFoundException;
import org.ow2.cmi.reference.ServerRef;
import org.ow2.util.pool.api.IPoolConfiguration;

public interface IEJBServerClusterViewManager {

    void addObjectInstance(ClusteredObjectInfo clusteredObjectInfo,
            CMIReference cmiReference) throws ServerClusterViewManagerException;

    void addPoolToEmpty(String objectName);

    void addServerToBlackList(ServerRef serverRef);

    Map<String, Set<String>> getAvailablePoliciesAndStrategies();

    String getBusinessName(String objectName) throws ObjectNotFoundException;

    Collection<CMIReference> getCMIReferences(String objectName)
            throws ObjectNotFoundException;

    Set<String> getClusterNames();

    InetAddress getInetAddress();

    String getItfName(String objectName) throws ObjectNotFoundException;

    JMXServiceURL getJMXServiceURL(String protocolName) throws ProtocolNotFoundException;

    int getNbClientsConnectedToProvider();

    Set<String> getObjectNames();

    Set<String> getObjectNames(String clusterName);

    List<String> getProviderURLs(String protocolName)
            throws ServerClusterViewManagerException;

    ServerRef getRefOnLocalRegistry(String protocolName) throws ProtocolNotFoundException;

    Set<String> getServerObjectForProtocol(String serverUrl, String protocolName)
            throws ProtocolNotFoundException;

    Set<ServerId> getServerRefs(String protocolName)
            throws ProtocolNotFoundException;

    boolean isReplicationManagerStarted();

    boolean isServerBlackListed(ServerRef serverRef);

    void removeCMIReference(CMIReference cmiReference);

    void removePoolToEmpty(String objectName);

    void removeServerFromBlackList(ServerRef serverRef);

    void setAlgorithmForPolicy(String objectName, String policyClassName,
            String strategyClassName, Map<String, Object> properties)
            throws ObjectNotFoundException;

    void setDelayToRefresh(int delay);

    void setLoadFactor(ServerRef serverRef, int loadFactor);

    void setPolicyClassName(String objectName, String policyClassName)
            throws ObjectNotFoundException;

    void setPoolConfiguration(String objectName,
            IPoolConfiguration poolConfiguration)
            throws ObjectNotFoundException;

    void setPropertiesForPolicy(String objectName,
            Map<String, Object> properties) throws ObjectNotFoundException;

    void setPropertyForPolicy(String objectName, String propertyName,
            Object propertyValue) throws ObjectNotFoundException;

    void setStrategyClassName(String objectName, String strategyClassName)
            throws ObjectNotFoundException;

    Set<String> getApplicationExceptionNames(String objectName)
            throws ObjectNotFoundException;

    Collection<CMIReference> getCMIReferences(String objectName, String protocolName)
            throws ObjectNotFoundException;

    String getClusterName(String objectName) throws ObjectNotFoundException;

    long getDateOfProperties(String objectName) throws ObjectNotFoundException;

    int getDelayToRefresh();

    String getInitialContextFactoryName(String protocolName) throws ProtocolNotFoundException;

    Class<?> getInterface(String objectName) throws ObjectNotFoundException;

    int getLoadFactor(ServerRef serverRef) throws ServerNotFoundException;

    IPolicy<CMIReference> getPolicy(String objectName)
            throws ObjectNotFoundException;

    Class<? extends IPolicy<?>> getPolicyClass(String objectName)
            throws ObjectNotFoundException, ClusterViewManagerException;

    String getPolicyClassName(String objectName) throws ObjectNotFoundException;

    IPoolConfiguration getPoolConfiguration(String objectName)
            throws ObjectNotFoundException;

    Map<String, Object> getPropertiesForPolicy(String objectName)
            throws ObjectNotFoundException;

    Object getPropertyForPolicy(String objectName, String propertyName)
            throws ObjectNotFoundException;

    Set<String> getProtocols();

    Class<? extends EJBObject> getRemoteClass(String objectName)
            throws ObjectNotFoundException;

    SessionId getSessionId();

    Class<? extends IStrategy<?>> getStrategyClass(String objectName)
            throws ObjectNotFoundException, ClusterViewManagerException;

    String getStrategyClassName(String objectName)
            throws ObjectNotFoundException;

    UUID getUUID();

    boolean hasState(String objectName) throws ObjectNotFoundException;

    boolean isClustered(String objectName);

    boolean isPoolToEmpty(String objectName) throws ObjectNotFoundException;

    boolean isReplicated(String objectName) throws ObjectNotFoundException;

}
